@@ -87,7 +87,7 @@ class Hoe
   include Rake::DSL if defined?(Rake::DSL)
 
   # duh
-  VERSION = "3.22.3"
+  VERSION = "3.24.0"
 
   @@plugins = [:clean, :debug, :deps, :flay, :flog, :newb, :package,
                :publish, :gemcutter, :signing, :test]
@@ -222,6 +222,18 @@ class Hoe
 
   attr_accessor :group_name
 
+  ##
+  # Optional: The name of the executables directory. [default: bin]
+
+  attr_accessor :bindir
+
+  ##
+  # Optional: The homepage of the project. Auto-populates to the home key
+  # of the urls read from the README.txt
+  #
+
+  attr_accessor :homepage
+
   ##
   # The Gem::Specification.
 
@@ -525,17 +537,18 @@ class Hoe
       s.version              = version if version
       s.summary              = summary
       s.email                = email
-      s.homepage             = urls["home"] || urls.values.first
+      s.homepage             = homepage || urls["home"] || urls.values.first
+
       s.description          = description
       s.files                = manifest
-      s.executables          = s.files.grep(/^bin/) { |f| File.basename(f) }
-      s.bindir               = "bin"
+      s.bindir               = bindir || "bin"
+      s.executables          = s.files.grep(/^#{s.bindir}/) { |f| File.basename(f) }
       s.require_paths        = dirs unless dirs.empty?
       s.rdoc_options         = ["--main", readme_file]
       s.post_install_message = post_install_message
       s.metadata             = (urls.keys & URLS_TO_META_MAP.keys).map { |name|
         [URLS_TO_META_MAP[name], urls[name]]
-      }.to_h
+      }.to_h if urls
 
       missing "Manifest.txt" if s.files.empty?
 
@@ -810,7 +823,9 @@ class Hoe
 
   def post_initialize
     activate_plugin_deps
-    intuit_values File.read_utf readme_file if readme_file
+    unless skip_intuit_values?
+      intuit_values File.read_utf readme_file if readme_file
+    end
     validate_fields
     define_spec
     load_plugin_tasks
@@ -840,20 +855,6 @@ class Hoe
     spec_extras[:required_ruby_version] = versions
   end
 
-  ##
-  # Declare that this gem requires ruby to be in the 1.8+ family.
-
-  def ruby18!
-    require_ruby_version "~> 1.8"
-  end
-
-  ##
-  # Declare that this gem requires ruby to be in the 1.9 family.
-
-  def ruby19!
-    require_ruby_version "~> 1.9"
-  end
-
   ##
   # Declare that this gem requires ruby to be in the 2.0+ family.
 
@@ -882,6 +883,9 @@ class Hoe
     require_ruby_version "~> 2.3"
   end
 
+  # I don't care for these methods (eg 3.0 is out) ... so I'm not
+  # continuing them.
+
   ##
   # Provide a linear degrading value from n to m over start to finis
   # dates. If not provided, start and finis will default to 1/1 and
@@ -907,6 +911,10 @@ class Hoe
     end
   end
 
+  def skip_intuit_values?
+    %w[summary description homepage].all? { |field| send field }
+  end
+
   ##
   # Loads ~/.hoerc, merges it with a .hoerc in the current pwd (if
   # any) and yields the configuration and its path
@@ -915,19 +923,29 @@ class Hoe
     config = Hoe::DEFAULT_CONFIG
 
     rc = File.expand_path("~/.hoerc")
-    exists = File.exist? rc
-    homeconfig = exists ? YAML.load_file(rc) : {}
+    homeconfig = maybe_load_yaml rc
 
     config = config.merge homeconfig
 
     localrc = File.join Dir.pwd, ".hoerc"
-    exists = File.exist? localrc
-    localconfig = exists ? YAML.load_file(localrc) : {}
+    localconfig = maybe_load_yaml(localrc)
 
     config = config.merge localconfig
 
     yield config, rc
   end
+
+  def maybe_load_yaml path
+    if File.exist? path then
+      if YAML.respond_to? :safe_load_file then
+        YAML.safe_load_file path, permitted_classes: [Regexp, Symbol]
+      else
+        YAML.load_file path
+      end
+    else
+      {}
+    end
+  end
 end
 
 class File
